==> worker_2.9.0.orig.tar.gz: worker-2.9.0/src/pdatei.h <==
/* pdatei.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2002-2004 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: pdatei.h,v 1.5 2004/10/27 21:08:29 ralf Exp $ */

#ifndef PDATEI_H
#define PDATEI_H

#include "wdefines.h"

#ifdef HAVE_LIBXPKMASTER
extern "C" {
#include <xpk/xpk.h>
#include <xpk/amigalibs.h>
}
#endif

class PDatei
{
 public:
  PDatei();
  ~PDatei();
  PDatei( const PDatei &other );
  PDatei &operator=( const PDatei &other );

  enum pdatei_handler { PDATEI_UNKNOWN, PDATEI_NORMAL, PDATEI_GZIP, PDATEI_BZIP2, PDATEI_XPK };
  int open( const char *filename );
  int read( void *buf, int size );
  void close();
  static enum pdatei_handler getCruncher( const char *filename );
  enum pdatei_handler getHandler();
 protected:
  enum pdatei_handler type;
  char *name;

#ifdef HAVE_LIBZ
  gzFile gzfp;
#endif

  FILE *fp;

#ifdef HAVE_LIBBZ2
  BZFILE *bzfp;
#endif

#ifdef HAVE_LIBXPKMASTER
  struct XpkFib *xpkfp;
  char *xpkbuf;
#endif
  
  char *readbuf;
  int readbuf_size, readbuf_used, readbuf_start;
  bool fileend;
};

#endif

==> worker_2.16.0.orig.tar.gz: worker-2.16.0/src/pdatei.h <==
/* pdatei.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2002-2006 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: pdatei.h,v 1.6 2006/02/08 20:45:06 ralf Exp $ */

#ifndef PDATEI_H
#define PDATEI_H

#include "wdefines.h"
#include <string>

class PDatei
{
 public:
  PDatei();
  ~PDatei();
  PDatei( const PDatei &other );
  PDatei &operator=( const PDatei &other );

  enum pdatei_handler { PDATEI_UNKNOWN, PDATEI_NORMAL, PDATEI_GZIP, PDATEI_BZIP2, PDATEI_XPK };
  int open( const char *filename );
  int read( void *buf, int size );
  void close();
  static enum pdatei_handler getCruncher( const char *filename );
  enum pdatei_handler getHandler();
 protected:
  enum pdatei_handler type;
  std::string name;
  int fd;
};

#endif
